@@ -2,8 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Massachusetts
-    Institute of Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -50,9 +50,9 @@ USA.
        (let ((expression (generate/expression expression)))
 	 (queue-map!/unsafe *generation-queue* (lambda (thunk) (thunk)))
 	 (let ((rgraphs
-		(list-transform-positive (reverse! *rgraphs*)
-		  (lambda (rgraph)
-		    (not (null? (rgraph-entry-edges rgraph)))))))
+		(filter (lambda (rgraph)
+			  (not (null? (rgraph-entry-edges rgraph))))
+			(reverse! *rgraphs*))))
 	   (for-each (lambda (rgraph)
 		       (rgraph/compress! rgraph)
 		       (rgraph/postcompress! rgraph))
@@ -128,16 +128,16 @@ USA.
        ;; provided that all of the procedure calls made by them are
        ;; reductions.
        (let loop ((block (procedure-block procedure)))
-	 (for-all? (block-children block)
-	   (lambda (block)
-	     (let ((procedure (block-procedure block)))
-	       (and (procedure? procedure)
-		    (if (procedure-continuation? procedure)
-			(continuation/always-known-operator? procedure)
-			;; Inline-coded child procedures are treated
-			;; as an extension of this procedure.
-			(or (not (procedure-inline-code? procedure))
-			    (loop block))))))))))))
+	 (every (lambda (block)
+		  (let ((procedure (block-procedure block)))
+		    (and (procedure? procedure)
+			 (if (procedure-continuation? procedure)
+			     (continuation/always-known-operator? procedure)
+			     ;; Inline-coded child procedures are treated
+			     ;; as an extension of this procedure.
+			     (or (not (procedure-inline-code? procedure))
+				 (loop block))))))
+		(block-children block)))))))
 
 (define (generate/procedure-entry/inline procedure)
   (generate/procedure-header procedure
@@ -185,11 +185,11 @@ USA.
 
 (define (continuation/avoid-check? continuation)
   (and (null? (continuation/returns continuation))
-       (for-all?
-	(continuation/combinations continuation)
+       (every
 	(lambda (combination)
 	  (let ((op (rvalue-known-value (combination/operator combination))))
-	    (and op (operator/needs-no-heap-check? op)))))))
+	    (and op (operator/needs-no-heap-check? op))))
+	(continuation/combinations continuation))))
 
 (define (operator/needs-no-heap-check? op)
   (and (rvalue/constant? op)
