@@ -2,8 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010, 2011 Massachusetts Institute of
-    Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -33,6 +33,10 @@ USA.
 "bigprm"
 "bitstr"
 "boot"
+"bytevector"
+"chacha12"
+"chacha20"
+"chacha8"
 "char"
 "daemon"
 "debug"
@@ -52,9 +56,11 @@ USA.
 "intern"
 "interp"
 "intprm"
+"keccak"
 "list"
 "lookprm"
 "lookup"
+"md5"
 "memmag"
 "missing"
 "obstack"
@@ -62,8 +68,11 @@ USA.
 "osscheme"
 "ostty"
 "outf"
+"prchacha"
 "prim"
 "primutl"
+"prkeccak"
+"prmd5"
 "ptrvec"
 "purify"
 "purutl"
@@ -76,7 +85,6 @@ USA.
 "sysprim"
 "term"
 "transact"
-"tterm"
 "utabmd"
 "utils"
 "vector"
